@@ -24,6 +24,25 @@
 #ifndef ANIMATION_H
 #define ANIMATION_H
 
+#include "mandvd_global.h"
+#include <mainfrm.h>
+#include <qlabel.h>
+#include <qtoolbutton.h>
+#include <qbuttongroup.h>
+#include <qlineedit.h>
+#include <qcombobox.h>
+#include <qslider.h>
+#include <qtextedit.h>
+#include <qspinbox.h>
+#include <qcheckbox.h>
+#include <qradiobutton.h>
+#include <qmessagebox.h>
+#include <qregexp.h>
+#include <qprogressbar.h>
+#include <qlistview.h>
+#include <qdatetimeedit.h>
+#include <dialog.h>
+
 /* Declarations for animations by Mikael */
 
 
