@@ -143,13 +143,13 @@
 #define PT_LBL1_25_2       "Durao da transio (seg.)"
 #define PT_BTAC2_2         "Alterar um captulo"
 #define PT_BTAINTRO        "Adicionar um vdeo de introduo ao DVD"
-#define PT_LBLl3_2         "Nesta etapa, voc ir inserir todos os vdeos e slideshows a serem apresentados no DVD. Voc pode tambm definir captulos em cada vdeo. \n\n Duplo clique nos vdeos listados abaixo para pr-visualiz-los."
+#define PT_LBLl3_2         "Nesta etapa, voc ir inserir todos os vdeos e slideshows a serem apresentados no DVD. Voc pode tambm definir captulos em cada vdeo. \n\nDuplo clique nos vdeos listados abaixo para pr-visualiz-los."
 
 #define PT_LBL1_20         "Seu boto do menu pode ser tanto algum texto, por exemplo o nome do vdeo, como uma imagem. Defina o que voc ir utilizar como boto com os controles abaixo."
 
 #define PT_LBL2_6          "Se voc deseja usar uma imagem como boto, defina uma imagem abaixo. Recomenda-se utilizar imagens no muito grandes."
 #define PT_LBL1_9          "<b>Informao do arquivo</b>"
-#define PT_LBL4_2          "<u>Endereo do vdeo :</u>"
+#define PT_LBL4_2          "<b>Endereo do vdeo :</b>"
 #define PT_LBL1_18         "Vdeo no recodificado"
 #define PT_LBL1_18_2       "Vdeo recodificado"
 #define PT_LBL1_3          "Ttulo do vdeo"
@@ -293,9 +293,8 @@
 #define PT_TBLMSG61        "Sim"
 #define PT_TBLMSG62        "No"
 #define PT_TBLMSG63        "Sobre "
-#define PT_TBLMSG64        "Este programa foi originalmente criado por Gibault Stephane (FR).\n Posteriormente foi atualizado por mim, Mikael B (micko@bag.org). A traduo\n para portugus brasileiro foi feita por Wille Marcel (wille@riseup.net).\n Este software  capaz de criar discos de DVD para serem tocados em players\n comuns. Eu encontrei o cdigo e fiz algumas modificaes que eu desejava.\n Principalmente por diverso e para aprender um pouco de QT.\n\n O autor original, Gibault pode voltar a trabalhar no software novamente\n para melhor-lo, se desejar. Porm o programa j tem timos recursos.\n At que Gibault ou algum outro bom programador queira continuar a\n desenvolver o ManDVD, eu posso fazer alguns hacks no cdigo. Por favor,\n reporte qualquer bug que voc encontrar, s no garanto que conseguirei\n corrigir todos :-) \n\n The ManDVD homepage: \n\n"
-
-
+#define PT_TBLMSG64        "Este programa foi originalmente criado por Gibault Stphane (FR).\nManuteno actual a cargo de Mikael Bhm (SE).\n\nEste software pode criar discos de DVD que podem ser reproduzidos em leitores normais.\nPor favor, envie relatrios de bugs atravs da homepage.\nTraduo para Ingls (PORTUGUS) por: Wille Marcel (wille@riseup.net).\n\nA pagina do homemDVD:"
+ 
 #define PT_TBLMSG65        "Abrir o arquivo"
 #define PT_TBLMSG66        "Escolha um arquivo de vdeo para importar"
 #define PT_TBLMSG67        "Escolha um arquivo de imagem para importar: "
@@ -308,6 +307,6 @@
 #define PT_TBLMSG73        "Selecione uma fonte para importar"
 #define PT_TBLMSG74        "Abrir um projeto do ManDVD"
 #define PT_TBLMSG75        "Codificando informao em "
-#define PT_TBLMSG76        " MB</B><br />Tamanho mximo  aprox.4400 MB"
+#define PT_TBLMSG76        " MB</B><br />Tamanho mximo  aprox. "
 
 #endif
\ No newline at end of file
