@@ -24,8 +24,24 @@
 #ifndef SUBTITLE_H
 #define SUBTITLE_H
 
+#include "mandvd_global.h"
+#include <mainfrm.h>
+#include <qlabel.h>
+#include <qtoolbutton.h>
+#include <qbuttongroup.h>
+#include <qlineedit.h>
+#include <qcombobox.h>
+#include <qtextedit.h>
+#include <qspinbox.h>
+#include <qslider.h>
+#include <qcheckbox.h>
+#include <qradiobutton.h>
+#include <qmessagebox.h>
+#include <qlistview.h>
+#include <qdatetimeedit.h>
+#include <qpushbutton.h>
+
 /* Declarations by Mikael */
 
 
-
 #endif
\ No newline at end of file
